*******************
Authors and Credits
*******************

Main author:

Nathaniel Starkman (`@nstarman <https://github.com/nstarman>`_)


Core Package Contributors
=========================

|Contributors|

All contributors (alphabetical last name):

* Mohamed Shaaban
* Nathaniel Starkman


Credits
=======

* Astropy: package template
* Jo Bovy: galpy package was also used as a template


.. |Contributors| image:: https://img.shields.io/github/contributors/nstarman/utilipy?style=flat
   :alt: GitHub contributors
